@@ -33,6 +33,11 @@ class JoinGraph(SQLReplacement):
             self._graph = self.build()
         return self._graph
 
+    def list_join_graphs(self):
+        graph = self.project.join_graph.graph
+        sorted_components = self._strongly_connected_components(graph)
+        return [f"subquery_{i}" for i, _ in enumerate(sorted_components)]
+
     def join_graph_hash(self, view_name: str) -> str:
         if view_name not in self._strong_graph_memo:
             graph = self.project.join_graph.graph
@@ -159,7 +164,7 @@ class JoinGraph(SQLReplacement):
             for field in self.project.fields(model=model)
             if field.canon_date and field.field_type == "measure"
         ]
-        mappings = model.get_mappings()
+        mappings = model.get_mappings(dimensions_only=True)
 
         # Merged result shared date and field mapping
         graph = networkx.DiGraph()
@@ -208,7 +213,6 @@ class JoinGraph(SQLReplacement):
             if not use_condition or (use_condition and join_hash in must_be_in):
                 measure_id = measure.id()
                 canon_date = self._get_field_with_memo(measure.canon_date, by_name=True)
-
                 for timeframe in canon_date.timeframes:
                     canon_date.dimension_group = timeframe
                     root_node_name = join_root + "_" + timeframe
